==> origami_database-0.0.5.tar.gz: lib/models/queryModel.dart <==
import 'package:origami_database/models/sortModel.dart';

class SelectModel{
  String name;
  String title;
  String function;
  SelectModel({ this.function,this.name,this.title});
  SelectModel.fromJson(dynamic data)
  {
    if(data.name)name=data.name;
    if(data.name)title=data.title;
    if(data.name)function=data.function;
  }
  dynamic toJson()
  {
    return{
      'name':name,
      'title':title,
      'function':function,
    };
  }
  static dynamic toList(List<SelectModel> list)
  {
    var l=[];
    if(list!=null)
    {
      for(var a in list)
      {
        l.add(a.toJson());
      }
    }
    return l;
  }
  static List<SelectModel> fromList(dynamic data)
  {
    var l=<SelectModel>[];
    for(var a in data)
    {
      l.add(SelectModel.fromJson(a));
    }
    return l;
  }
}
class QueryModel
{
  dynamic where;
  int top;
  int skip;
  List<SelectModel> select;
  List<SortModel> sort=<SortModel>[];

  QueryModel({this.where,this.select,this.skip,this.top,this.sort});
  QueryModel. fromJson(dynamic data)
  { 
    if(data['where']!=null) where=data['where'];
    if(data['top']!=null) top=data['top'];
    if(data['skip']!=null) skip=data['skip'];
    if(data['select']!=null) select=SelectModel.fromList(data['select']);
    if(data['sort']!=null) sort=SortModel.fromJsonList(data['sort']);
  }
  dynamic toJson()
  {
    return {
      'where':where,
      'skip':skip,
      'top':top,
      'select':SelectModel.toList(select),
      'sort':SortModel.toJsonList(sort),
    };
  }
}

==> origami_database-0.0.8.tar.gz: lib/models/queryModel.dart <==
import 'package:origami_database/models/sortModel.dart';

class SelectModel{
  String name;
  String title;
  String function;
  SelectModel({ this.function,this.name,this.title});
  SelectModel.fromJson(dynamic data)
  {
    if(data.name)name=data.name;
    if(data.name)title=data.title;
    if(data.name)function=data.function;
  }
  dynamic toJson()
  {
    return{
      'name':name,
      'title':title,
      'function':function,
    };
  }
  static dynamic toList(List<SelectModel> list)
  {
    var l=[];
    if(list!=null)
    {
      for(var a in list)
      {
        l.add(a.toJson());
      }
    }
    return l;
  }
  static List<SelectModel> fromList(dynamic data)
  {
    var l=<SelectModel>[];
    for(var a in data)
    {
      l.add(SelectModel.fromJson(a));
    }
    return l;
  }
}
class QueryModel
{
  dynamic where;
  int top;
  int skip;
  bool count;
  List<SelectModel> select;
  List<SortModel> sort=<SortModel>[];

  QueryModel({this.where,this.select,this.skip,this.top,this.sort,this.count});
  QueryModel. fromJson(dynamic data)
  { 
    if(data['where']!=null) where=data['where'];
    if(data['top']!=null) top=data['top'];
    if(data['skip']!=null) skip=data['skip'];
    if(data['count']!=null) count=data['count'];
    if(data['select']!=null) select=SelectModel.fromList(data['select']);
    if(data['sort']!=null) sort=SortModel.fromJsonList(data['sort']);
  }
  dynamic toJson()
  {
    return {
      'where':where,
      'skip':skip,
      'count':count,
      'top':top,
      'select':SelectModel.toList(select),
      'sort':SortModel.toJsonList(sort),
    };
  }
}
